from .folder_structure_view import(
    get_folder_overview,
    # __all__ as __all_folder_structure_view__
)

from .clone import(
    copy_num_folders,
    copy_folders,
    batch_file_overwrite,
    # __all__ as __all_clone__
)

# from .folder_structure_view import __all__ as __all_folder_structure_view__
# from .clone import __all__ as __all_clone_

# __all__  = __all_folder_structure_view__ + __all_clone_

# # stop polluting name space
# del __all_folder_structure_view__
# del __all_clone_
